==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm2015/lib/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep, Point_$type } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let PolarAreaSeries = /*@__PURE__*/ (() => {
    class PolarAreaSeries extends PolarLineSeriesBase {
        bi() {
            return new PolarAreaSeries();
        }
        get_es() {
            return true;
        }
        cq() {
            return new PolarAreaSeriesView(this);
        }
        zp() {
            return false;
        }
        qw(a) {
            super.qw(a);
            this.acl = a;
        }
        constructor() {
            super();
            this.ab = PolarAreaSeries.$;
        }
        acj(a) {
            let b = a;
            b.da();
        }
        ack(a, b) {
            if (a.m.count > 0) {
                let c = a.m._inner[0];
                let d = a.m._inner[a.m.count - 1];
                let e = c.x == d.x && c.y == d.y;
                if (!e) {
                    a.m.add(a.m._inner[0]);
                }
            }
            let f = b;
            f.db(a.m, this.ib);
            this.yw.az(this, this.zo(), runOn(this, this.ye));
            let g = false;
            let h = this.yw.b;
            if (h != null) {
                g = true;
            }
            if (g) {
                this.aa3(-1, this.za.count, b.q);
            }
            let i = f.dh;
            let j = f.dg;
            this.yw.ad(i, true, false, true, true);
            this.yw.ad(j, false, true, false, false);
            j._opacity = this.yw.j * this.h7;
        }
        get_acg() {
            return true;
        }
        acb() {
            return this.acm;
        }
    }
    PolarAreaSeries.$t = /*@__PURE__*/ markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    PolarAreaSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:acm:aco', [UnknownValuePlotting_$type, /*@__PURE__*/ enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarAreaSeries;
})();
/**
 * @hidden
 */
export let PolarAreaSeriesView = /*@__PURE__*/ (() => {
    class PolarAreaSeriesView extends PolarLineSeriesBaseView {
        constructor(a) {
            super(a);
            this.c9 = null;
            this.df = new Path();
            this.de = new Path();
            this.dd = new Path();
            this.dc = new Path();
            this.c9 = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.c9.w1 = Defaults.e;
            }
        }
        get dg() {
            return this.de;
        }
        get dh() {
            return this.df;
        }
        da() {
            this.de.an = null;
            this.df.an = null;
            this.dc.an = null;
            this.dd.an = null;
            this.as();
        }
        db(a, b) {
            let c = new List$1(Point_$type, 1, a);
            this.c9.ab8.d(this.df, c, b);
            this.c9.ab8.d(this.de, c, b);
            this.as();
        }
        bd() {
            super.bd();
        }
        be() {
            super.be();
            let a = this.br();
            this.dd.an = this.df.an;
            this.dc.an = this.de.an;
            this.dd._stroke = a;
            this.dd.ad = this.e.ic + 3;
            this.dc._fill = a;
            this.dc._opacity = 1;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                if (b) {
                    a.t(this.dc);
                    a.t(this.dd);
                }
                else {
                    a.t(this.de);
                    a.t(this.df);
                }
            }
        }
        an(a) {
            super.an(a);
            this.e.bb.exportPathData(a, this.df, "polarShape", ["Main"]);
            this.e.bb.exportPathData(a, this.de, "fillShape", ["Fill"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.vu = a;
            this.e.jk = 5;
            this.e.jl = 5;
            this.e.jm = 5;
        }
    }
    PolarAreaSeriesView.$t = /*@__PURE__*/ markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
})();

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm2015/lib/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep, Point_$type } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let PolarAreaSeries = /*@__PURE__*/ (() => {
    class PolarAreaSeries extends PolarLineSeriesBase {
        bj() {
            return new PolarAreaSeries();
        }
        get_eu() {
            return true;
        }
        cs() {
            return new PolarAreaSeriesView(this);
        }
        zy() {
            return false;
        }
        q1(a) {
            super.q1(a);
            this.acu = a;
        }
        constructor() {
            super();
            this.ab = PolarAreaSeries.$;
        }
        acs(a) {
            let b = a;
            b.da();
        }
        act(a, b) {
            if (a.m.count > 0) {
                let c = a.m._inner[0];
                let d = a.m._inner[a.m.count - 1];
                let e = c.x == d.x && c.y == d.y;
                if (!e) {
                    a.m.add(a.m._inner[0]);
                }
            }
            let f = b;
            f.db(a.m, this.id);
            this.y5.az(this, this.zx(), runOn(this, this.yn));
            let g = false;
            let h = this.y5.b;
            if (h != null) {
                g = true;
            }
            if (g) {
                this.abc(-1, this.zj.count, b.q);
            }
            let i = f.dh;
            let j = f.dg;
            this.y5.ad(i, true, false, true, true);
            this.y5.ad(j, false, true, false, false);
            j._opacity = this.y5.j * this.h9;
        }
        get_acp() {
            return true;
        }
        ack() {
            return this.acv;
        }
    }
    PolarAreaSeries.$t = /*@__PURE__*/ markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    PolarAreaSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:acv:acx', [UnknownValuePlotting_$type, /*@__PURE__*/ enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarAreaSeries;
})();
/**
 * @hidden
 */
export let PolarAreaSeriesView = /*@__PURE__*/ (() => {
    class PolarAreaSeriesView extends PolarLineSeriesBaseView {
        constructor(a) {
            super(a);
            this.c9 = null;
            this.df = new Path();
            this.de = new Path();
            this.dd = new Path();
            this.dc = new Path();
            this.c9 = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.c9.xa = Defaults.e;
            }
        }
        get dg() {
            return this.de;
        }
        get dh() {
            return this.df;
        }
        da() {
            this.de.an = null;
            this.df.an = null;
            this.dc.an = null;
            this.dd.an = null;
            this.as();
        }
        db(a, b) {
            let c = new List$1(Point_$type, 1, a);
            this.c9.ach.d(this.df, c, b);
            this.c9.ach.d(this.de, c, b);
            this.as();
        }
        bd() {
            super.bd();
        }
        be() {
            super.be();
            let a = this.br();
            this.dd.an = this.df.an;
            this.dc.an = this.de.an;
            this.dd._stroke = a;
            this.dd.ad = this.e.ie + 3;
            this.dc._fill = a;
            this.dc._opacity = 1;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                if (b) {
                    a.t(this.dc);
                    a.t(this.dd);
                }
                else {
                    a.t(this.de);
                    a.t(this.df);
                }
            }
        }
        an(a) {
            super.an(a);
            this.e.bc.exportPathData(a, this.df, "polarShape", ["Main"]);
            this.e.bc.exportPathData(a, this.de, "fillShape", ["Fill"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.v1 = a;
            this.e.jm = 5;
            this.e.jn = 5;
            this.e.jo = 5;
        }
    }
    PolarAreaSeriesView.$t = /*@__PURE__*/ markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
})();
